SUBROUTINE DEPTH(KB,Z,DZ,DZR,DZZ,ZZ,DSBOT)
!***BEGIN PROLOGUE DEPTH
!***DATE WRITTEN   910904 (YYMMDD)
!***REVISION DATE  910904 (YYMMDD)
!***AUTHOR
!            Jarle Berntsen, Institute of Marine Research,
!            Postboks 1870,
!            N-5024 Bergen-Nordnes, Norway
!            Email..  jarle.berntsen@mi.uib.no
!
!***PURPOSE DEPTH computes the array Z,DZ,DZR,DZZ and ZZ
!
!   DSBOT is the sigma-thickness of the bottom and surface layers
!   and must be given by the user if the below formulae by Lynch
!   et al. is to be applied.
!
!
!***END PROLOGUE DEPTH
!
!   Global variables.
!
  IMPLICIT NONE
  INTEGER KB
  REAL Z(KB),DZ(KB),DZR(KB),DZZ(KB),ZZ(KB)
  REAL DSBOT
!
!   Local variables.
!
  INTEGER K
  REAL DELTAEPS,PI,AA,EPS
  LOGICAL :: LYNCH_DISTRIBUTION=.TRUE.

!
!   This part of DEPTH may have to be modified from one
!   implementation to the other.
!
!
!***FIRST EXECUTABLE STATEMENT DEPTH
!
!   Compute Z.
  
  LYNCH_DISTRIBUTION=.FALSE.
  
  IF(LYNCH_DISTRIBUTION)THEN
      
!   Here we are using the algorithm due to Lynch et.al,1995.
!   Convergence Studies of Tidally-Rectified Circulation on Georges Bank.
!   In: Quantitative Skill Assessment for Coastal Ocean Models,
!   Lynch,D.R. and Davies,A.M. (editors), American Geophysical Union.
!
      DELTAEPS = 1.0/(KB-1.)
      PI = 4.*ATAN(1.0)
      AA = (DELTAEPS - DSBOT)/SIN(2.*PI*DELTAEPS)
      DO K = 1,KB
          EPS = (K-1.)/(KB-1.)
          Z(KB + 1 - K) = -1. + EPS - AA*SIN(2*PI*EPS)
      END DO
  ELSE

!
!   When focusing on fjord studies with fresh water runoff it is probably
!   better to have better resolution of the surface layer as suggested below.
!
      DO K = 1,6
          Z(K) = -(K-1)*.005
      END DO
      Z(7) = -0.025 - 0.006
      Z(8) = -0.031 - 0.007
      Z(9) = -0.038 - 0.008
      Z(10) = -0.046 - 0.009
      Z(11) = -0.055 - 0.010
      Z(12) = -0.065 - 0.012
      Z(13) = -0.077 - 0.014
      Z(14) = -0.091 - 0.016
      Z(15) = -0.107 - 0.018
      Z(16) = -0.125 - 0.020
      Z(17) = -0.145 - 0.025
      Z(18) = -0.170 - 0.030
      Z(19) = -0.200 - 0.040
      Z(20) = -0.240 - 0.050
      Z(21) = -0.290 - 0.060
      Z(22) = -0.350 - 0.070
      Z(23) = -0.420 - 0.080
      Z(24) = -0.500 - 0.090
      Z(25) = -0.590 - 0.100
      Z(26) = -0.690 - 0.100
      Z(27) = -0.790 - 0.100
      Z(28) = -0.890 - 0.050
      Z(29) = -0.940 - 0.025
      Z(30) = -0.965 - 0.015
      Z(31) = -0.980 - 0.010
      Z(32) = -0.990 - 0.010
  END IF

!
  DO K = 1,KB
      DZ(K)=0.0
      DZR(K)=0.0
      DZZ(K)=0.0
  END DO
!
!   Compute ZZ.
!
  DO K = 1,KB-1
      ZZ(K)=(Z(K)+Z(K+1))/2.
  END DO
  ZZ(KB) = 0.
!
!    Compute DZ,DZZ and DZR.
!
  DO K = 1,KB-1
      DZ(K)=Z(K)-Z(K+1)
      DZR(K)=1./DZ(K)
      DZZ(K)=ZZ(K)-ZZ(K+1)
  END DO
!
!   Write out the depth parameters.
!
  WRITE(*,70)
70 FORMAT(/2X,'K',7X,'Z',9X,'ZZ',9X,'DZ',9X,'DZZ',/)
  DO K = 1,KB
      WRITE(*,80) K,Z(K),ZZ(K),DZ(K),DZZ(K)
  END DO
80 FORMAT(' ',I5,4F10.3)
!
!***END DEPTH
!
  RETURN
END SUBROUTINE DEPTH
